package
Version:
v1.0.1-0...-20e81f0
Opens a new window with list of versions in this module.
Published: Nov 17, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewConfig return a config
IsSourceJSON returns true if source format is json
type Request struct {
EventID string
Data []byte `json:"data"`
}
Request represents a service request
Response represents a response
NewResponse creates a response
Service service to proxy pubsub topic payload to google storage with or without validation
New create a service service
Singleton returns new service for env key
Source Files
¶
Click to show internal directories.
Click to hide internal directories.