package
Version:
v1.0.1-0...-20e81f0
Opens a new window with list of versions in this module.
Published: Nov 17, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Request struct {
Dest string
Data []byte
Attributes map[string]interface{}
}
Request represents request
type Response struct {
MessageIDs []string
}
Response represents response
Service represents message bus service
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.